SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetProcesses]
(
	@VCC						VARCHAR(50) = NULL,
	@SearchCriteria				VARCHAR(50) = NULL,
	@SearchExpression			VARCHAR(50) = NULL,
	@StartDate					DATETIME,
	@EndDate					DATETIME,
	@Type						VARCHAR(50),
	@Environment				VARCHAR(50) = NULL,
	@Language					VARCHAR(50) = NULL
)
AS
BEGIN
	DECLARE @SQL NVARCHAR(MAX)
	IF @Type = 'ALL'
	BEGIN 
		SELECT [name],[name] as 'description',[type],[BatchScheduleId] as 'batchScheduleId'
			FROM dbo.[Process] (NOLOCK)
			WHERE [Status] = 'COMPLETE'
				AND [Type] = 'SPEECH'
				AND [VCC] = @VCC
				AND [Environment] = @Environment
				AND [Language] = @Language
		UNION ALL
		SELECT P.[name],EP.[Id] as 'description' ,[type],P.[BatchScheduleId] 
			FROM dbo.[Process] P (NOLOCK)
			INNER JOIN  dbo.[EvaluationPlan] (NOLOCK) EP 
				ON P.[VCC] = EP.[Instance]
					AND P.[Name] = EP.[ProcessId]
					AND P.[Status] = 'COMPLETE'
					AND P.[Type] = 'QUALITY'
					AND P.[VCC] = @VCC
					AND P.[Environment] = @Environment
					AND P.[Language] = @Language
					AND EP.[Status] = 7
			INNER JOIN (
			  SELECT [processId], MAX([CreatedDate]) AS CreatedDate
				FROM dbo.[EvaluationPlan] (NOLOCK) 
				WHERE [Instance] =  @VCC
					AND [ProcessId] IS NOT NULL
					AND [Status] = 7
				GROUP BY [ProcessId]
			  ) AS QPEP
			  ON EP.[ProcessId] = QPEP.[ProcessId]
				AND EP.[CreatedDate] = QPEP.[CreatedDate]

	END
	ELSE
	BEGIN
		SET @SQL = '
		SET NOCOUNT ON

		SELECT [VCC]																				''vcc'',
				[Name]																				''name'',
				[Description]																		''description'',
				[ClientId]																			''clientId'',
				[Percentage]																		''percentage'',
				[StatusDescription]																	''statusDescription'',
				(CASE WHEN [Status] IS NULL THEN ''UNKNOWN'' ELSE [Status] END)						''status'',
				[StartDate]																			''startDate'',
				[EndDate]																			''endDate'',
				[MinDurationTime]																	''minDurationTime'',
				[MaxDurationTime]																	''maxDurationTime'',
				[Language]																			''language'',
				[Environment]																		''environment'',
				[BatchScheduleId]																	''batchScheduleId'',
				[CreatedDate]																		''createdDate'',
				[CreatedByUserId]																	''createdByUserId'',
				[LastModifiedDate]																	''lastModifiedDate'',
				[LastModifiedByUserId]																''lastModifiedByUserId''
			FROM [Process] (NOLOCK)
			WHERE [VCC] = ''' + @VCC + '''
				AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
				AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
				AND ISNULL([ClientId], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''clientId'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
				AND ISNULL([Status], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''status'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
				AND ISNULL([Environment], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''environment'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'

		IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
		BEGIN
			SET @SQL += '
				AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			'
		END
		SET @SQL += '
				AND [Type] = ''' + @Type + '''
		ORDER BY [Status] desc, [CreatedDate] desc 

		SET NOCOUNT OFF
		'
		EXEC(@SQL)
	END
ENDGO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
